@@ -3,9 +3,6 @@ from .app import App
 # import pybi.core.styles as styles
 from pybi.core.styles import *
 from pybi.easyEcharts import *
-from pybi.core import Sql
-
-# import pyvisflow.core.user_utils
 
 
 app = App()
@@ -49,7 +46,7 @@ flowBox = app.flowBox
 box = app.box
 to_json = app.to_json
 set_dataView = app.set_dataView
-sql = Sql
+sql = app.sql
 clear_all_data = app.clear_all_data
 _save_db = app.save_db
 save_zip_db = app.save_zip_db
