@@ -3,16 +3,15 @@ from typing import TYPE_CHECKING, List, Union
 
 
 from pybi.core.components import ComponentTag
-from pybi.core.sql import Sql
 from .base import SingleReactiveComponent
 
 
 if TYPE_CHECKING:
-    pass
+    from pybi.core.sql import SqlInfo
 
 
 class Slicer(SingleReactiveComponent):
-    def __init__(self, sql: Sql) -> None:
+    def __init__(self, sql: SqlInfo) -> None:
         super().__init__(ComponentTag.Slicer, sql)
         self.title = ""
         self.multiple = True
